@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 our $SOURCE = 'CPAN';
 ## $SOURCE = 'GitHub';  # COMMENT
 # the line above will be commented out by Dist::Zilla
@@ -659,16 +659,17 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Packy Anderson Alexey Melezhik jira JRC Atlassian GreenHopper ScriptRunner
-TODO aggregateprogress aggregatetimeestimate aggregatetimeoriginalestimate
-assigneeType avatar avatarUrls completeDate displayName duedate
-emailAddress endDate fieldtype fixVersions fromString genericized iconUrl
-isAssigneeTypeValid issueTypes issuekeys issuelinks issuetype jql
-lastViewed maxResults originalEstimate originalEstimateSeconds parentkey
-projectId rapidViewId remainingEstimate remainingEstimateSeconds
-resolutiondate sprintlist startDate subtaskIssueTypes timeSpent
-timeSpentSeconds timeestimate timeoriginalestimate timespent timetracking
-toString updateAuthor worklog workratio
+=for :stopwords Packy Anderson Alexandr Alexey Ciornii Melezhik jira JRC Atlassian
+GreenHopper ScriptRunner TODO aggregateprogress aggregatetimeestimate
+aggregatetimeoriginalestimate assigneeType avatar avatarUrls completeDate
+displayName duedate emailAddress endDate fieldtype fixVersions fromString
+genericized iconUrl isAssigneeTypeValid issueTypes issuekeys issuelinks
+issuetype jql lastViewed maxResults originalEstimate
+originalEstimateSeconds parentkey projectId rapidViewId remainingEstimate
+remainingEstimateSeconds resolutiondate sprintlist startDate
+subtaskIssueTypes timeSpent timeSpentSeconds timeestimate
+timeoriginalestimate timespent timetracking toString updateAuthor worklog
+workratio
 
 =head1 NAME
 
@@ -676,7 +677,7 @@ JIRA::REST::Class::Mixins - An mixin class for L<JIRA::REST::Class|JIRA::REST::C
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 METHODS
 
