@@ -1,7 +1,7 @@
 package InlineTest;
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 use JSON::PP;
 
